@@ -1,10 +1,12 @@
 import logging
 import os
-from os.path import join as path_join, expanduser, abspath
+from os.path import join as path_join, expanduser, abspath, dirname
 
 import click_log
 
-TEMPLATE_FOLDER = "templates"
+logger = logging.getLogger(__name__)
+
+click_log.basic_config(logger)
 
 TEMPLATE_EXTS = {
     "python": "py",
@@ -21,10 +23,10 @@ if CLOUDINARY_HOME is None:
     CLOUDINARY_HOME = abspath(path_join(expanduser("~"), ".cloudinary-cli"))
 
 CLOUDINARY_CLI_CONFIG_FILE = abspath(path_join(CLOUDINARY_HOME, 'config.json'))
-CUSTOM_TEMPLATE_FOLDER = abspath(path_join(CLOUDINARY_HOME, 'templates'))
 
-OLD_CLOUDINARY_CLI_CONFIG_FILE = abspath(path_join(expanduser("~"), '.cloudinary-cli-config'))
+TEMPLATE_FOLDER_NAME = 'templates'
+CLOUDINARY_CLI_ROOT = dirname(__file__)
+TEMPLATE_FOLDER = path_join(CLOUDINARY_CLI_ROOT, TEMPLATE_FOLDER_NAME)
+CUSTOM_TEMPLATE_FOLDER = path_join(abspath(CLOUDINARY_HOME), TEMPLATE_FOLDER_NAME)
 
-logger = logging.getLogger(__name__)
-
-click_log.basic_config(logger)
+OLD_CLOUDINARY_CLI_CONFIG_FILE = path_join(expanduser("~"), '.cloudinary-cli-config')
