@@ -1,9 +1,9 @@
 import unittest
 
-from cloudinary_cli.utils.file_utils import get_destination_folder
+from cloudinary_cli.utils.file_utils import get_destination_folder, walk_dir
 
 
-class UtilsTest(unittest.TestCase):
+class FileUtilsTest(unittest.TestCase):
     def test_get_destination_folder(self):
         """ should parse option values correctly """
 
@@ -14,3 +14,10 @@ class UtilsTest(unittest.TestCase):
                                                 "/Users/user/myfolder/subfolder/file.jpg",
                                                 parent="/Users/user/"))
 
+    def test_walk_dir(self):
+        """ should skip hidden files in the directory """
+
+        test_dir = "test_resources/test_file_utils"
+
+        self.assertEqual(1, len(walk_dir(test_dir, include_hidden=False)))
+        self.assertEqual(4, len(walk_dir(test_dir, include_hidden=True)))
